# -*- coding: utf-8 -*-
import random
import operator
import os
import Image

class UploadPicture():
    def __init__(self):
        self.path = ''
        self.smallPath = ''
        self.thumbPath = ''

    def readFile(self, file):
        # If the file is big, it will be saved to /tmp
        # and will have the attribute temporary_file_path
        if hasattr(file, 'temporary_file_path'):
            self.path = file.temporary_file_path()
            self.image = Image.open(self.path)
        else:
            self.path = '/tmp/image-tmp-' + str(random.randint(1000, 9999))
            destination = open(self.path, 'wb+')
            for chunk in file.chunks():
                destination.write(chunk)
            destination.close()
            # If it's not an image, it will abort
            self.image = Image.open(self.path)
        self.__readAttributes()
        self.__getThumbnail()
        self.__getSmallVersion()

    def __readAttributes(self):
        self.width = self.image.size[0]
        self.height = self.image.size[1]
        self.type = self.image.format.lower()
        if self.type != 'gif' and self.type != 'jpeg' and self.type != 'png':
            raise Exception
        elif self.type == 'jpeg':
            self.contentType='image/jpeg'
        elif self.type == 'gif':
            self.contentType='image/gif'
        elif self.type == 'png':
            self.contentType='image/png'

    def __getThumbnail(self):
        if self.width >= self.height:
            scaleFactor = self.width / 160.0
            self.thumb_height = int(self.height / scaleFactor)
            self.thumb_width = 160
        else:
            scaleFactor = self.height / 160.0
            self.thumb_width = int(self.width / scaleFactor)
            self.thumb_height = 160
        thumb = self.image.resize((self.thumb_width, self.thumb_height), Image.ANTIALIAS)
        self.thumbPath = self.path + '-thumb.jpeg'
        thumb.save(self.thumbPath, quality=85)

    def __getSmallVersion(self):
        if self.width <= 640 <= self.height and self.type == "jpeg":
            self.smallPath = self.path
        else :
            if self.width >= self.height:
                scaleFactor = self.width / 640.0
                self.small_height = int(self.height / scaleFactor)
                self.small_width = 640
            else:
                scaleFactor = self.height / 640.0
                self.small_width = int(self.width / scaleFactor)
                self.small_height = 640
            small = self.image.resize((self.small_width, self.small_height), Image.ANTIALIAS)
            self.smallPath = self.path + '-small.jpeg'
            small.save(self.smallPath, quality=85)

    def renameFiles(self, stamp):
        # Don't know if this will introduce bugs
        os.chdir('/tmp')
        if self.smallPath != self.path:
            newPath = stamp + '.' + self.type
            os.rename(self.path, newPath)
            self.path = newPath

            newPath = stamp + '-small.jpeg'
            os.rename(self.smallPath, newPath)
            self.smallPath = newPath
        else:
            newPath = stamp + '.' + self.type
            os.rename(self.path, newPath)
            self.smallPath = newPath
            self.path = newPath
        newPath = stamp + '-thumb.jpeg'
        os.rename(self.thumbPath, newPath)
        self.thumbPath = newPath

    def delete_pictures(self):
        os.chdir('/tmp')
        if self.smallPath != self.path and os.path.exists(self.thumbPath):
            os.remove(self.smallPath)
        if os.path.exists(self.thumbPath):
            os.remove(self.thumbPath)
        if os.path.exists(self.path):
            os.remove(self.path)

def tag_frequencies(posts):
    frequencies= {}
    for post in posts:
        for tag in post.tags:
            if frequencies.has_key(tag):
                frequencies[tag] += 1
            else:
                frequencies[tag] = 1
    frequencies = sorted(frequencies.iteritems(), key=operator.itemgetter(1), reverse=True)
    return [ item[0] for item in frequencies ][:10]