# -*- coding: utf-8 -*-
from django.http import Http404
from django.shortcuts import render_to_response, redirect
from django.core.urlresolvers import reverse
from django.contrib.auth.decorators import user_passes_test
from django.template.context import RequestContext
from forms import TagsDetailForm
from models import Tag
from posts.models import Post
from utils.helper import Paginator

# TODO: query other stuff
def list(request):
    items_per_page = 50
    page = 1
    query = None
    try:
        if request.GET.get('page'):
            page = int(request.GET['page'])
        else:
            page = 1
        # TODO: More queries and variable picture count on one page
        if request.GET.get('type'):
            query = Q(type__in=request.GET['type'])
            type_html = 'type=' + request.GET['type'] + '&'
        else:
            type_html = ''
    except:
        type_html = ''

    tags = Tag.objects(query)[:items_per_page]

    count = Tag.objects(query).only().count()
    paginator = Paginator(count, items_per_page)
    paginator.set_page(page)
    paginator.html_query = reverse('tags.views.list') + '?' + type_html +  'page='

    return render_to_response('tags/list.html', {'tags': tags,
                                                 'paginator': paginator,}, context_instance=RequestContext(request))

@user_passes_test(lambda u: u.is_staff)
def details(request, tag):
    tag = Tag.objects(name=tag).first()
    if tag is None:
        raise Http404

    if request.method == 'POST':
        form = TagsDetailForm(request.POST)
        if form.is_valid():
            if tag.name != form.cleaned_data['name']:
                # Remember: You need to rename EVERY reference!
                posts = Post.objects(tags__all=[tag.name])
                posts.update(push__tags=form.cleaned_data['name'])
                posts.update(pull__tags=tag.name)
                tag.name = form.cleaned_data['name']
            tag.type = form.cleaned_data['type']
            tag.save()
            return redirect('tags.views.list')

    data = {'name': tag.name, 'type': tag.type }
    form = TagsDetailForm(data)

    # We need the RequestContext for the CSRF protection
    return render_to_response('tags/details.html', {'form': form, 'tag': tag}, context_instance=RequestContext(request))